@@ -1175,7 +1175,7 @@ def run():
 
     # Destroy services and exit
     if options.destroy_services or options.terminate_machines:
-        log.debug("Resetting environment...")
+        log.info("Resetting environment...")
         env.connect()
         env.reset(terminate_machines=options.terminate_machines,
                   terminate_delay=options.deploy_delay,
